@@ -20,7 +20,7 @@
 #constants for File API
 
 class Params:
-    allowedRetrievalTypes = ('pending', 'published', 'pseudo')
+    allowedRetrievalTypes = ('pending', 'published', 'pseudo', 'contextMatchingInstrumented')
 
     API_KEY    = 'apiKey'
     PROJECT_ID = 'projectId'
@@ -33,6 +33,10 @@ class Params:
     RETRIEVAL_TYPE = 'retrievalType'
     FILE_URI_NEW   = 'newFileUri'
     CALLBACK_URL    = 'callbackUrl'
+    LOCALES_TO_APPROVE = 'localesToApprove'
+    LOCALE_IDS = 'localeIds'
+    LOCALE_IDS_BRACKET = 'localeIds[]'
+    FILE_URIS   = 'fileUris'
 
 class Uri:
     base = '/v1/file/'
@@ -47,5 +51,24 @@ class Uri:
 
 class ReqMethod:
     POST   = "POST"
-    GET    = "POST"
+    GET    = "GET"
     DELETE = "DELETE"
+
+class FileTypes:
+    android        = "android"
+    ios            = "ios"
+    gettext        = "gettext"
+    html           = "html"
+    javaProperties = "javaProperties"
+    yaml           = "yaml"
+    xliff          = "xliff"
+    xml            = "xml"
+    json           = "json"
+    docx           = "docx"
+    pptx           = "pptx"
+    xlsx           = "xlsx"
+    idml           = "idml"
+    qt             = "qt"
+    resx           = "resx"
+    plaintext      = "plaintext"
+    cvs            = "cvs"
