@@ -24,6 +24,7 @@ class UploadData:
     """ Helper class to store `upload` and `import` command attributes """
     approveContent = "false"
     callbackUrl = ""
+    localesToApprove = []
 
     def __init__(self, path, name, type):
         self.path = path
@@ -37,9 +38,12 @@ class UploadData:
 
     def setCallbackUrl(self, callbackUrl):
         self.callbackUrl = callbackUrl
+        
+    def setLocalesToApprove(self, localesToApprove):
+        self.localesToApprove = localesToApprove
 
     def addDirective(self, directive):
         self.directives.append(directive)
 
     def setUri(self, uri):
-        self.uri = uri
\ No newline at end of file
+        self.uri = uri
